Skip to contents

Provides the bootstrap-calibrated local-influence goodness-of-fit test for simplex regression models with constant or varying dispersion.

The methodology is described in Ospina, Espinheira, Silva and Barros (2026). This package is authored and maintained by Raydonal Ospina.

Main functions:

simplex_fitFit a simplex regression model via MLE.
simplex_gofParametric-bootstrap GoF test.
simplex_diagInfluence diagnostics and test quantities.
plot_influenceInfluence index plot.
plot_envelopeHalf-normal plot with bootstrap envelope.
plot_gof_bootBootstrap distribution of \(U_n\).
paper_ammoniaReproduce ammonia application from the paper.
paper_pbscReproduce PBSC application from the paper.
rsimplexRandom generation from the simplex distribution.
sim_table1Monte Carlo size/power study.

Datasets: ammonia (n = 21) and pbsc (n = 239).

References

Ospina R., Espinheira P.L., Silva F.C., Barros M. (2026). A Bootstrap-Calibrated Local Influence Goodness-of-Fit Procedure for Simplex Regression Models.

Author

Author and Maintainer: Raydonal Ospina raydonal@de.ufpe.br (ORCID)